#!/bin/sh
#
# Component: cases
#
# Description:
#    Checks the status of the given repository (default is $REPOSITORY_DICOM_DATA), 
#	 manages the state of the DISK_FULL flag, and calls IMMessage to display warnings when necessary
#
# Usage:
#   checkRepositoryStatus.sh [repository]
#
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh

repository=$1
[ -z "$repository" ] && repository="$REPOSITORY_DICOM_DATA"

repName=`basename "$repository"`

[ "$repository" = "$REPOSITORY_DICOM_DATA" ] && repName="dicom_data"

[ "$repository" = "$REPOSITORY_CACHE" ] && repName="cache"

[ "$repository" = "$REPOSITORY_PROCESSED" ] && repName="processed"

diskfull="false"

if [ "$repository" = "$REPOSITORY_DICOM_DATA" ] ; then
	# check home partition
	diskFullLim=97
	[ -f "$CONF/limit.conf" ] && . $CONF/limit.conf
	if [ -n ${SAFETY_FREE_LIMIT} ] ; then
		diskFullLim=$((100 - ${SAFETY_FREE_LIMIT} / 2))
		echo $repository - $diskFullLim
	fi
	USED_PERCENT=`df -P $HOME | tail -n 1 | awk '{print $5}' | sed 's;%$;;'`
	if [ ${USED_PERCENT} -ge ${diskFullLim} ] ; then
		touch $DISK_FULL_FLAG_FILE
		diskfull="true"
	fi
fi

errorbits=`$REPOSITORYHANDLER_HOME/bin/getRepositoryStatus $repository`
if [ $? -eq 0 ] ; then
	if [ "$repository" = "$REPOSITORY_DICOM_DATA" ] ; then
		[ "$diskfull" != "true" ] && rm $DISK_FULL_FLAG_FILE 2>/dev/null
	fi
fi

javaMsg_() {
	$TASKD_HOME/runjavacmd -c "0 imagemed.util.IMMessageWrapper $repName $1" -p "$JAVA_SERVER_PORT"
}

for errorbit in $errorbits ; do 
	if [ "$repository" = "$REPOSITORY_DICOM_DATA" -a "$errorbit" = "WARN3" ] ; then
		touch $DISK_FULL_FLAG_FILE
		diskfull="true"
	fi
	[ "$errorbit" = "INCOMPLETE" ] && incomplete="true"
	[ "$errorbit" = "MISSING" ] && missing="true"
	[ "$errorbit" = "WARN" ] && warn="true"
	[ "$errorbit" = "REMIND" ] && remind="true"
done

[ "$repository" = "$REPOSITORY_DICOM_DATA" -a "$diskfull" != "true" ] && rm $DISK_FULL_FLAG_FILE 2>/dev/null

if [ "$missing" = "true" ] ; then
	javaMsg_ "MISSING"
elif [ "$incomplete" = "true" ] ; then
	javaMsg_ "INCOMPLETE"
else
	javaMsg_ "COMPLETE"
fi

if [ "$diskfull" != "true" ] ; then
	javaMsg_ "NONFULL"
fi

if [ "$warn" = "true" ] ; then
	javaMsg_ "WARN"
elif [ "$remind" = "true" ] ; then
	javaMsg_ "REMIND"
else
	javaMsg_ "NONE"
fi

if [ "$diskfull" = "true" ] ; then
	javaMsg_ "FULL"
fi
