#!/bin/sh
#
# Component: checkintegrity
#
# Description:
#      Checks if a study is consistent.
#
# Usage:
#      checkStudy.sh [-r] [-d] [-c <config file>] [-C <config setting>]... -s <study>
#
#       -r                   : recover mode
#       -d                   : print debug information
#       -s <study>           : study instance UID of the studiy to be checked
#       -c <config file>     : configuration file to be used instead of var/checkintegrity/integrity.conf
#       -C <config setting>  : config setting to be added to the settings set in the configuration file
#		  -F						  : sets mode to full
#	     -P					     : sets mode to partial
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh

STUDY=""
RECOVER=""
DEBUG=""
CONFIGFILE_OPT=""
CONFIGSETTING_OPT=""
MODE=""
while getopts 's:c:C:rdFP' OPT; do
	case $OPT in
		s) STUDY="$OPTARG" ;;
		c) CONFIGFILE_OPT="-c \"$OPTARG\"" ;;
		C) CONFIGSETTING_OPT="$CONFIGSETTING_OPT -C \"$OPTARG\"" ;;
		r) RECOVER="-r" ;;
		d) DEBUG="-d" ;;
		F) MODE="-F" ;;
		P) MODE="-P" ;;
		*)  ;;
	esac
done

if [ -z "$STUDY" ] ; then
	echo "Missing argument: Study Instance UID" >&2
	exit
fi

logFile="$TMP/checkintegrity.log.$$"

$TASKD_HOME/runjavacmd -c "0 imagemed.checkintegrity.CheckStudy -s $STUDY $CONFIGFILE_OPT $CONFIGSETTING_OPT -l $logFile $RECOVER $DEBUG $MODE" -p $JAVA_SERVER_PORT

cat $logFile
rm $logFile
