#!/bin/sh
#
# Component: dotcom
#
# Description:
#  OBSOLETE [7.0]
#  Uploads a file to a remote dotcom server and optionally start a script on the remote server to
#  process the uploaded file
#
# Usage:
#   See usage_() function below
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh


# if upload.sh is called directly:
# run as a task instead
if [ `basename $0` = "upload.sh" ] ; then
	$TASKD_HOME/runshellcmd.sh -R -r 0 $0 "$@"
	exit $?
fi


LOGGER="/usr/bin/logger"
TAG="upload[$$]"

#
# Usage
#
usage_()
{
	if [ -n "$1" ] ; then
		echo $1
		$LOGGER -p $LOG_FACILITY.err -t "$TAG" "$1"
	fi
	cat <<- ENDOFUSAGE
		upload.sh -f <filename> {-H <hostId | -h <host> [-p port] [-s]}
			  [[-r script] [-a scriptarg]...]
	
		 -f <filename>      : the file to upload
		 -H <hostId>        : device ID of the device to upload the file to
		 -r <script>        : run this script on target after upload
		 -a <scriptarg>     : params passed to script
		 -R <refcount type> : Remove "uploadto_\$host" references from <refcount type> after upload
		 -I <refcount ID>   : Refcount identifier (= \`basename <filename>\` in default)

		 Obsolete options:
		 -h <host>          : upload the file to this host
		 -p <port>          : use this port for upload (default http(s) port)
		 -s                 : use https protocol for upload
	
		If -R option is provided it's supposed that an 'uploadto_\$host' reference has been added to
		the refcount ID (file) before. This reference will be removed at the end of this script
	
	ENDOFUSAGE
} # usage_


ERRMSG=""
FILENAME=""
HOSTIP=""
HOSTID=""
SCHEME="http"
# PORT=""
SCRIPTNAME=""
SCRIPTARGS=""

REFCOUNTTYPE=""
REFCOUNTID=""

PASS_PARAMS=""


[ -z "$RETRY_NUM" ] && RETRY_NUM=0

ERRMSG=""

while getopts 'f:H:h:x:p:r:a:R:I:sn' OPT; do
	case $OPT in
		f) FILENAME="$OPTARG" ; PASS_PARAMS="$PASS_PARAMS -f \"$OPTARG\"" ;;
		h) HOSTIP="$OPTARG" ; PASS_PARAMS="$PASS_PARAMS -h \"$OPTARG\"" ;;
		H) HOSTID="$OPTARG" ; PASS_PARAMS="$PASS_PARAMS -H \"$OPTARG\"" ;;
#		p) PORT="$OPTARG" ;;
		s) SCHEME="https" ; PASS_PARAMS="$PASS_PARAMS -s \"$OPTARG\"" ;;
		r) SCRIPTNAME="$OPTARG" ; PASS_PARAMS="$PASS_PARAMS -r \"$OPTARG\"" ;;
		R) REFCOUNTTYPE="$OPTARG" ; PASS_PARAMS="$PASS_PARAMS -R \"$OPTARG\"" ;;
		I) REFCOUNTID="$OPTARG" ; PASS_PARAMS="$PASS_PARAMS -I \"$OPTARG\"" ;;
		a) PASS_PARAMS="$PASS_PARAMS -a \"$OPTARG\"" ; if [ -z "$SCRIPTARGS" ] ; then
				SCRIPTARGS="$OPTARG"
			else
				SCRIPTARGS="$SCRIPTARGS\n$OPTARG"
			fi ;;
		*) ERRMSG="Invalid_Parameter:$OPT" ;;
	esac
done

HOST="$HOSTID"
[ -z "$HOST" ] && HOST="$HOSTIP"

if [ -z "$FILENAME" -o -z "$HOST" ] ; then
	ERRMSG="Missing Parameter"
fi

# include nettask.shi for checking if the device is temporary down
. $TASKD_HOME/nettask.shi

# override getPeer_() of nettask.shi
getPeer_()
{
	echo "$HOST"
}


run_() # override run_ method
{
	if [ -n "$ERRMSG" ] ; then
		usage_ "$ERRMSG"
		return 125
	fi

	$TASKD_HOME/runjavacmd -c "0 dotcom.Upload $PASS_PARAMS" -p "$JAVA_SERVER_PORT"
	ERR=$?

	exit $ERR
}

print_()
{
	$TASKD_HOME/runjavacmd -c "print dotcom.Upload $PASS_PARAMS" -p "$JAVA_SERVER_PORT"
}

cleanup_()
{
	$TASKD_HOME/runjavacmd -c "cleanup dotcom.Upload $PASS_PARAMS" -p "$JAVA_SERVER_PORT"
}
